@@ -298,9 +298,17 @@ def _build_inputs(
                 field_name=field_name, gql_field=gql_field
             )
             if for_strawberry:
+                pure_type = get_pure_type(gql_type=gql_field.type)
+                if pure_type not in scalar_d.values():
+                    python_line = python_line.replace(
+                        str(pure_type), f"Strawberry.{pure_type}"
+                    )
                 ending = "" if "..." in python_line else " = None"
                 python_line = f'{python_line[:python_line.index(" =")]}{ending}'
             field_str_lst.append(python_line)
+        if for_strawberry:
+            # sort field_str_lst for straw putting required fields first
+            field_str_lst.sort(key=lambda _: _.count("="))
         fields_str = "\n".join(field_str_lst)
         class_str = f"class {type_name}({ORM_MODEL_NAME}):"
         if for_strawberry:
@@ -722,7 +730,7 @@ class EnhancedJSONEncoder(json.JSONEncoder):
         if isinstance(gql_type, graphql.GraphQLEnumType):
             if not type_name.startswith("__"):
                 enum_names.append(type_name)
-    enums_str = "\n".join([f"strawberry.enum({name})" for name in enum_names])
+    enums_str = "\n".join([f"{name} = strawberry.enum({name})" for name in enum_names])
 
     inputs_s = build_inputs(schema=schema, for_strawberry=True)
     lines = [
